==> PyQtGuiLib-1.0.9.4-py3-none-any.whl: PyQtGuiLib/header/Qt/qtWidgets.py <==
from PyQtGuiLib.header.versions import PYQT_VERSIONS
if PYQT_VERSIONS == "PyQt5":
    from PyQt5.QtWidgets import (
        QApplication,
        QWidget,
        QFrame,
        QStackedWidget,
        QLabel,
        QPushButton,
        QLineEdit,
        QTextBrowser,
        QGroupBox,
        QGridLayout,
        QVBoxLayout,
        QHBoxLayout,
        QCheckBox,
        QInputDialog,
        QComboBox,
        QMenu,
        QTableWidget,
        QScrollArea,
        QWidgetItem,
        QSplitter,
        QGraphicsOpacityEffect,
        QMainWindow,
        QDesktopWidget as DesktopWidget,
        QGraphicsDropShadowEffect,
        QSlider,
        QListWidget,
        QListWidgetItem,
        QListView,
        QAction,
        QAbstractScrollArea,
        QRadioButton,
        QSpacerItem,
        QSizePolicy,
        QStyle,
        QStyleOption,
        QStyledItemDelegate,
        QLayout,
        QLayoutItem,
        QStyleOptionViewItem
    )
if PYQT_VERSIONS == "PyQt6":
    from PyQt6.QtWidgets import (
        QApplication,
        QWidget,
        QFrame,
        QStackedWidget,
        QLabel,
        QPushButton,
        QLineEdit,
        QTextBrowser,
        QGroupBox,
        QGridLayout,
        QVBoxLayout,
        QHBoxLayout,
        QCheckBox,
        QInputDialog,
        QComboBox,
        QMenu,
        QTableWidget,
        QScrollArea,
        QWidgetItem,
        QSplitter,
        QGraphicsOpacityEffect,
        QMainWindow,
        QGraphicsDropShadowEffect,
        QSlider,
        QListWidget,
        QListWidgetItem,
        QListView,
        QAbstractScrollArea,
        QRadioButton,
        QSpacerItem,
        QSizePolicy,
        QStyle,
        QStyleOption,
        QStyledItemDelegate,
        QLayout,
        QLayoutItem,
        QStyleOptionViewItem

)

if PYQT_VERSIONS == "PySide2":
    from PySide2.QtWidgets import (
        QApplication,
        QWidget,
        QFrame,
        QStackedWidget,
        QLabel,
        QPushButton,
        QLineEdit,
        QTextBrowser,
        QGroupBox,
        QGridLayout,
        QVBoxLayout,
        QHBoxLayout,
        QCheckBox,
        QInputDialog,
        QComboBox,
        QMenu,
        QTableWidget,
        QScrollArea,
        QWidgetItem,
        QSplitter,
        QGraphicsOpacityEffect,
        QMainWindow,
        QDesktopWidget as DesktopWidget,
        QGraphicsDropShadowEffect,
        QSlider,
        QListWidget,
        QListWidgetItem,
        QListView,
        QAction,
        QAbstractScrollArea,
        QRadioButton,
        QSpacerItem,
        QSizePolicy,
        QStyle,
        QStyleOption,
        QStyledItemDelegate,
        QLayout,
        QLayoutItem,
        QStyleOptionViewItem
    )

if PYQT_VERSIONS == "PySide6":
    from PySide6.QtWidgets import (
        QApplication,
        QWidget,
        QFrame,
        QStackedWidget,
        QLabel,
        QPushButton,
        QLineEdit,
        QTextBrowser,
        QGroupBox,
        QGridLayout,
        QVBoxLayout,
        QHBoxLayout,
        QCheckBox,
        QInputDialog,
        QComboBox,
        QMenu,
        QTableWidget,
        QScrollArea,
        QWidgetItem,
        QSplitter,
        QGraphicsOpacityEffect,
        QMainWindow,
        QGraphicsDropShadowEffect,
        QSlider,
        QListWidget,
        QListWidgetItem,
        QListView,
        QAbstractScrollArea,
        QRadioButton,
        QSpacerItem,
        QSizePolicy,
        QStyle,
        QStyleOption,
        QStyledItemDelegate,
        QLayout,
        QLayoutItem,
        QStyleOptionViewItem
    )

==> PyQtGuiLib-2.2.17.8-py3-none-any.whl: PyQtGuiLib/header/Qt/qtWidgets.py <==
from PyQtGuiLib.header.versions import PYQT_VERSIONS
if PYQT_VERSIONS == "PyQt5":
    from PyQt5.QtWidgets import (
        QApplication,
        QWidget,
        QFrame,
        QStackedWidget,
        QLabel,
        QPushButton,
        QLineEdit,
        QTextBrowser,
        QGroupBox,
        QGridLayout,
        QVBoxLayout,
        QHBoxLayout,
        QCheckBox,
        QInputDialog,
        QComboBox,
        QMenu,
        QTableWidget,
        QScrollArea,
        QWidgetItem,
        QSplitter,
        QGraphicsOpacityEffect,
        QMainWindow,
        QDesktopWidget as DesktopWidget,
        QGraphicsDropShadowEffect,
        QSlider,
        QListWidget,
        QListWidgetItem,
        QListView,
        QAction,
        QAbstractScrollArea,
        QRadioButton,
        QSpacerItem,
        QSizePolicy,
        QStyle,
        QStyleOption,
        QStyledItemDelegate,
        QLayout,
        QLayoutItem,
        QStyleOptionViewItem,
        QTreeWidget,
        QTreeWidgetItem,
        QTreeWidgetItemIterator,
        QTextBrowser,
        QTextEdit,
        QTabWidget,
        QSpinBox,
        QDoubleSpinBox,
        QFormLayout,
        QColorDialog,
        QToolButton,
        QMessageBox,
        QMenuBar,
        QDialog,
        QDateEdit,
        QDateTimeEdit,
        QGraphicsBlurEffect,
        QGraphicsColorizeEffect,
        QWizard,
        QWizardPage
    )
if PYQT_VERSIONS == "PyQt6":
    from PyQt6.QtWidgets import (
        QApplication,
        QWidget,
        QFrame,
        QStackedWidget,
        QLabel,
        QPushButton,
        QLineEdit,
        QTextBrowser,
        QGroupBox,
        QGridLayout,
        QVBoxLayout,
        QHBoxLayout,
        QCheckBox,
        QInputDialog,
        QComboBox,
        QMenu,
        QTableWidget,
        QScrollArea,
        QWidgetItem,
        QSplitter,
        QGraphicsOpacityEffect,
        QMainWindow,
        QGraphicsDropShadowEffect,
        QSlider,
        QListWidget,
        QListWidgetItem,
        QListView,
        QAbstractScrollArea,
        QRadioButton,
        QSpacerItem,
        QSizePolicy,
        QStyle,
        QStyleOption,
        QStyledItemDelegate,
        QLayout,
        QLayoutItem,
        QStyleOptionViewItem,
        QTreeWidget,
        QTreeWidgetItem,
        QTreeWidgetItemIterator,
        QTextBrowser,
        QTextEdit,
        QTabWidget,
        QSpinBox,
        QDoubleSpinBox,
        QFormLayout,
        QColorDialog,
        QToolButton,
        QMessageBox,
        QMenuBar,
        QDialog,
        QDateEdit,
        QDateTimeEdit,
        QGraphicsBlurEffect,
        QGraphicsColorizeEffect,
        QWizard,
        QWizardPage
)

if PYQT_VERSIONS == "PySide2":
    from PySide2.QtWidgets import (
        QApplication,
        QWidget,
        QFrame,
        QStackedWidget,
        QLabel,
        QPushButton,
        QLineEdit,
        QTextBrowser,
        QGroupBox,
        QGridLayout,
        QVBoxLayout,
        QHBoxLayout,
        QCheckBox,
        QInputDialog,
        QComboBox,
        QMenu,
        QTableWidget,
        QScrollArea,
        QWidgetItem,
        QSplitter,
        QGraphicsOpacityEffect,
        QMainWindow,
        QDesktopWidget as DesktopWidget,
        QGraphicsDropShadowEffect,
        QSlider,
        QListWidget,
        QListWidgetItem,
        QListView,
        QAction,
        QAbstractScrollArea,
        QRadioButton,
        QSpacerItem,
        QSizePolicy,
        QStyle,
        QStyleOption,
        QStyledItemDelegate,
        QLayout,
        QLayoutItem,
        QStyleOptionViewItem,
        QTreeWidget,
        QTreeWidgetItem,
        QTreeWidgetItemIterator,
        QTextBrowser,
        QTextEdit,
        QTabWidget,
        QSpinBox,
        QDoubleSpinBox,
        QFormLayout,
        QColorDialog,
        QToolButton,
        QMessageBox,
        QMenuBar,
        QDialog,
        QDateEdit,
        QDateTimeEdit,
        QGraphicsBlurEffect,
        QGraphicsColorizeEffect,
        QWizard,
        QWizardPage
    )

if PYQT_VERSIONS == "PySide6":
    from PySide6.QtWidgets import (
        QApplication,
        QWidget,
        QFrame,
        QStackedWidget,
        QLabel,
        QPushButton,
        QLineEdit,
        QTextBrowser,
        QGroupBox,
        QGridLayout,
        QVBoxLayout,
        QHBoxLayout,
        QCheckBox,
        QInputDialog,
        QComboBox,
        QMenu,
        QTableWidget,
        QScrollArea,
        QWidgetItem,
        QSplitter,
        QGraphicsOpacityEffect,
        QMainWindow,
        QGraphicsDropShadowEffect,
        QSlider,
        QListWidget,
        QListWidgetItem,
        QListView,
        QAbstractScrollArea,
        QRadioButton,
        QSpacerItem,
        QSizePolicy,
        QStyle,
        QStyleOption,
        QStyledItemDelegate,
        QLayout,
        QLayoutItem,
        QStyleOptionViewItem,
        QTreeWidget,
        QTreeWidgetItem,
        QTreeWidgetItemIterator,
        QTextBrowser,
        QTextEdit,
        QTabWidget,
        QSpinBox,
        QDoubleSpinBox,
        QFormLayout,
        QColorDialog,
        QToolButton,
        QMessageBox,
        QMenuBar,
        QDialog,
        QDateEdit,
        QDateTimeEdit,
        QGraphicsBlurEffect,
        QGraphicsColorizeEffect,
        QWizard,
        QWizardPage
    )
